###############
gm3dh5.exporter
###############

.. rubric:: Modules

.. currentmodule:: gm3dh5.exporter

.. autosummary::
   :toctree: generated
   :template: custom-module-template.rst

   neper
   csv

.. rubric:: Methods

.. autosummary::
   :toctree: generated
   :template: custom-function-template.rst

   dump
